@@ -194,7 +194,7 @@ print.gmvarpred <- function(x, ..., digits=2) {
     pred_type <- gmvarpred$pred_type
     for(i1 in seq_len(gmvarpred$gmvar$model$d)) {
       cat(paste0("Component ", i1, ":"), "\n")
-      df <- as.data.frame(lapply(1:length(pred_ints), function(i2) format_value(pred_ints[[i2]][,i1])))
+      df <- as.data.frame(lapply(1:length(gmvarpred$q), function(i2) format_value(pred_ints[, i2, i1])))
       names(df) <- q
       df[, pred_type] <- format_value(pred[,i1])
       if(gmvarpred$pi_type == "two-sided") {
@@ -207,6 +207,9 @@ print.gmvarpred <- function(x, ..., digits=2) {
       print(df[, new_order])
       cat("\n")
     }
+    if(gmvarpred$pred_type != "cond_mean") {
+      cat("Point forecasts and prediction intervals for mixing weights can be obtained with $mix_pred and $mix_pred_ints, respectively.\n")
+    }
   }
   invisible(gmvarpred)
 }
