@@ -6,7 +6,7 @@
 #'
 #' @inheritParams simulateGMVAR
 #' @return Returns \eqn{((n_obs-p) x d)} matrix containing the multivariate quantile residuals,
-#'   \eqn{j}:th column corresponds the time series in the \eqn{j}:th column of the data. The multivariate
+#'   \eqn{j}:th column corresponds to the time series in the \eqn{j}:th column of the data. The multivariate
 #'   quantile residuals are calculated so that the first column quantile residuals are the "unconditioned ones"
 #'   and the rest condition on all the previous ones in numerical order. Read the cited article by
 #'   \emph{Kalliovirta and Saikkonen 2010} for details.
@@ -18,7 +18,7 @@
 #'          Time Series Models. \emph{Unpublished Revision of HECER Discussion Paper No. 247}.
 #'  }
 #' @seealso \code{\link{fitGMVAR}}, \code{\link{GMVAR}}, \code{\link{quantile_residual_tests}},
-#'   \code{\link{diagnostic_plot}}, \code{\link{predict.gmvar}}
+#'   \code{\link{diagnostic_plot}}, \code{\link{predict.gmvar}}, \code{\link{profile_logliks}}
 #' @examples
 #' # These examples use the data 'eurusd' which comes with the
 #' # package, but in a scaled form.
@@ -90,31 +90,32 @@ quantile_residuals <- function(gmvar) {
   all_boldA <- form_boldA(p=p, M=M, d=d, all_A=all_A)
   alphas <- pick_alphas(p=p, M=M, d=d, params=params)
 
-  # An i:th row denotes the vector \bold{y_{i-1}} = (y_{i-1}',...,y_{i-p}') (dpx1), assuming the observed data is y_{-p+1},...,y_0,y_1,...,y_{T}
+  # An i:th row denotes the vector \bold{y_{i-1}} = (y_{i-1}',...,y_{i-p}') (dpx1),
+  # assuming the observed data is y_{-p+1},...,y_0,y_1,...,y_{T}
   Y <- reform_data(data, p)
 
   # Mixing weights
   alpha_mt <- gmvar$mixing_weights
 
-  # Calculate the conditional means mu_{m,t} (Kalliovirta et al. 2016, Condition 1 (a)).
+  # Calculate the conditional means mu_{m,t} (KMS 2016, Condition 1 (a)).
   # Map to dimensions of mu_mt: [t, p, m]
   all_A2 <- array(all_A, dim=c(d, d*p, M)) # cbind coefficient matrices of each component: m:th component is obtained at [, , m]
   Y2 <- Y[1:T_obs,] # Last row is not needed because mu_mt uses lagged values
   mu_mt <- array(vapply(1:M, function(m) t(all_phi0[, m] + tcrossprod(all_A2[, , m], Y2)), numeric(d*T_obs)), dim=c(T_obs, d, M)) # [, , m]
 
   ## Start computing the multivariate quantile residuals (Kalliovirta and Saikkonen 2010, eq.(4))
-  # Using properties of marginal and conditional distributions of multinormal random variables and
+  # using properties of marginal and conditional distributions of multinormal random variables and
   # applying them to the mixture components at each time point t.
 
-  # Compute partitions and matrix products of partioned covariance matrices Omega that will be used multiple times
-  upleft_jjmat <- function(mat, j) mat[1:j,1:j, drop=FALSE]
+  # Compute partitions and matrix products of partioned covariance matrices Omega that will be used multiple times.
+  upleft_jjmat <- function(mat, j) mat[1:j, 1:j, drop=FALSE]
 
-  # Store variances and conditional variances (obtained from multinormal)
+  # Storage for variances and conditional means (obtained from multinormal)
   variances <- matrix(nrow=d, ncol=M) # Column per mixture component and row per component
   mu_mtj <- array(dim=c(T_obs, d, M)) # [t, j, m]
 
   # Calculate variances and means (both conditional for j=2,...,d) for t=1,...,T, m=1,...,M, j=1,...,d
-  dat <- data[(p+1):nrow(data),] # Remove starting values
+  dat <- data[(p + 1):nrow(data),] # Remove the initial values
   for(m in 1:M) {
     variances[1, m] <- all_Omega[1, 1, m] # "Marginal" variance
     mu_dif <- dat - mu_mt[, , m] # mu_mt - y_t, t = 1,...,T
@@ -122,24 +123,24 @@ quantile_residuals <- function(gmvar) {
 
     for(j in 2:d) {
       Omega_mj <- upleft_jjmat(all_Omega[, , m], j)
-      up_left <- upleft_jjmat(Omega_mj, j-1)
-      up_right <- Omega_mj[1:(j-1), j, drop=FALSE] # (j-1 x 1)
+      up_left <- upleft_jjmat(Omega_mj, j - 1)
+      up_right <- Omega_mj[1:(j - 1), j, drop=FALSE] # (j-1 x 1)
       low_left <- t(up_right)
       low_right <- Omega_mj[j, j]
 
       matprod <- low_left%*%solve(up_left) # (1 x j-1)
       variances[j, m] <- low_right - matprod%*%up_right # Conditional variance conditioned to components 1,..,j-1
-      mu_mtj[, j, m] <- mu_mt[, j, m] + t(matprod%*%t(mu_dif[,1:(j-1)]))
+      mu_mtj[, j, m] <- mu_mt[, j, m] + t(tcrossprod(matprod, mu_dif[, 1:(j - 1), drop=FALSE])) #t(matprod%*%t(mu_dif[,1:(j-1)]))
     }
   }
 
-  # Calculate beta_{m,t,j} for j=2,...,d (Virolainen 2018, eq. (1.12) work paper)
+  # Calculate beta_{m,t,j} for j=2,...,d (Virolainen 2018, eq. (1.12) unpublished work paper)
   beta_mtj <- array(dim=c(T_obs, M, d)) # [t, m, j] j=1,...,d
   beta_mtj[, , 1] <- alpha_mt
   for(j in 2:d) {
-    log_mvnvalues <- vapply(1:M, function(m) dlogmultinorm(y=dat[,1:(j-1), drop=FALSE],
-                                               mu=as.matrix(mu_mt[, 1:(j-1), m]),
-                                               Omega=upleft_jjmat(all_Omega[, , m], j-1)),
+    log_mvnvalues <- vapply(1:M, function(m) dlogmultinorm(y=dat[,1:(j - 1), drop=FALSE],
+                                                           mu=as.matrix(mu_mt[, 1:(j - 1), m]),
+                                                           Omega=upleft_jjmat(all_Omega[, , m], j - 1)),
                                              numeric(T_obs))
     if(any(log_mvnvalues < epsilon)) { # Use Brobdingnag
       numerators <- lapply(1:M, function(m) alpha_mt[,m]*exp(Brobdingnag::as.brob(log_mvnvalues[,m])))
@@ -158,7 +159,7 @@ quantile_residuals <- function(gmvar) {
 
   F_values <- vapply(1:d, function(j) rowSums(as.matrix(beta_mtj[, , j]*pnorm(points_mtj[, j, ]))), numeric(T_obs))
 
-  # Values too close to 0 or 1 will be scaled so that qnorm doesn' return inf-values
+  # Values too close to 0 or 1 will be scaled so that qnorm doesn't return inf-values
   F_values[F_values >= 1 - .Machine$double.eps/2] <- 1 - .Machine$double.eps/2
   F_values[F_values <= .Machine$double.eps/2] <- .Machine$double.eps/2
 
@@ -168,7 +169,7 @@ quantile_residuals <- function(gmvar) {
 
 #' @title Calculate multivariate quantile residuals of GMVAR model
 #'
-#' @description \code{quantile_residuals_int} is a simple wrapper for \code{quantile_residuals} to compute
+#' @description \code{quantile_residuals_int} is a wrapper for \code{quantile_residuals} to compute
 #'   quantile residuals using parameter values instead of class \code{gmvar} object.
 #'
 #' @inheritParams loglikelihood_int
@@ -215,7 +216,7 @@ quantile_residuals_int <- function(data, p, M, params, conditional, parametrizat
 #' @param mu dimension \eqn{(T x k)} matrix where each row is the mean of the k-dimensional
 #'   random vector in corresponding row of \code{y}.
 #' @param Omega the \eqn{(k x k)} covariance matrix Omega.
-#' @return size \eqn{(T x 1)} vector containing the multinormal densities in logarithm
+#' @return Returns a size \eqn{(T x 1)} vector containing the multinormal densities in logarithm.
 
 dlogmultinorm <- function(y, mu, Omega) {
   tmp <- -0.5*ncol(y)*log(2*pi) - 0.5*log(det(Omega))
