@@ -3,6 +3,11 @@ library(gmvarkit)
 
 data <- cbind(10*eurusd[,1], 100*eurusd[,2])
 
+## NOTE: For some reason these tests fail at win-builder with tolerance smaller than 1e-2 (while they pass locally).
+# Apparently, when testing diagonal of the observed information matrix, the tests pass, but when testing
+# diagonal of its inverse (or the standard errors), the tests fail (with average difference about 1e-3).
+# Possibly a numerical error caused by (the default) imprecission of float-point presentation?
+
 ## A(M)(p)_(p)(M)(d)
 
 # p=2, M=2, d=2
@@ -44,14 +49,14 @@ alpha1_222_c2 <- 0.35
 theta_222_c2 <- c(phi10_222_c2, phi20_222_c2, 1.26, 1.34, -0.29, -0.36, vech(Omega1_222_c2),
                   vech(Omega2_222_c2), alpha1_222_c2)
 
-
 test_that("standard_errors works correctly", {
-  expect_equal(standard_errors(data, p=2, M=2, params=theta_222c, conditional=TRUE, parametrization="intercept",
-                               constraints=C_222, minval=-99999),
-               c(0.5732, 1.4271, 0.6841, 1.7985, 0.0650, 0.0952, 0.0346, 0.0612, 0.0634, 0.0959, 0.0349, 0.0645,
-                 0.1562, 0.2720, 0.7288, 0.7295, 0.7322, 1.1896, 0.2887), tolerance=1e-2)
-  expect_equal(standard_errors(data, p=2, M=2, params=theta_222_c2, conditional=TRUE, parametrization="intercept",
-                               constraints=C_222_2, minval=-99999),
-               c(NA, 0.7255, NA, 0.8365, 0.0572, 0.0576, 0.0589, 0.0576, 0.0323, NA, 0.8578, 0.6916,
-                 0.7216, 1.1712, 0.3959), tolerance=1e-2)
+   expect_equal(standard_errors(data, p=2, M=2, params=theta_222c, conditional=TRUE, parametrization="intercept",
+                                constraints=C_222, minval=-99999),
+                c(0.57323112, 1.42708542, 0.68407209, 1.79850113, 0.06503308, 0.09518451, 0.03464635, 0.06118081, 0.06339426,
+                  0.09592758, 0.03487118, 0.06453526, 0.15615508, 0.27195919, 0.72882509, 0.72951956, 0.73219670, 1.18963949,
+                  0.28865116), tolerance=1e-2)
+   expect_equal(standard_errors(data, p=2, M=2, params=theta_222_c2, conditional=TRUE, parametrization="intercept",
+                                constraints=C_222_2, minval=-99999),
+                c(NA, 0.7887294, NA, 0.92849143, 0.05692548, 0.05744037, 0.05888322, 0.05761173, NA, NA, 0.85622084,
+                  0.68689890, 0.72052650, 1.16661586, 0.40045562), tolerance=1e-2)
 })
